@@ -1,4 +1,4 @@
-#if defined(SYSV)
+#ifndef HAVE_FLOCK
 #ifndef _FLOCK_EMULATE_INCLUDED
 #define _FLOCK_EMULATE_INCLUDED
 
@@ -23,4 +23,23 @@
 extern int flock();
 
 #endif /* _FLOCK_EMULATE_INCLUDED */
-#endif /* SYSV */
+#endif /* HAVE_FLOCK */
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
