@@ -22,7 +22,12 @@ typedef unsigned char *POINTER;
 typedef unsigned short int UINT2;
 
 /* UINT4 defines a four byte word */
+#if (SIZEOF_UNSIGNED_LONG_INT != 4)
+/* This should cover 64bit OS' */
+typedef unsigned int UINT4;
+#else
 typedef unsigned long int UINT4;
+#endif
 
 /* PROTO_LIST is defined depending on how PROTOTYPES is defined above.
 If using PROTOTYPES, then PROTO_LIST returns the list, otherwise it
