@@ -3,16 +3,16 @@
  * All rights reserved.  The Berkeley software License Agreement
  * specifies the terms and conditions for redistribution.
  */
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
 
-#ifndef lint
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_dele.c	2.1  2.1 3/18/91";
-#endif
 
+#include <config.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <ctype.h>
-#include "popper.h"
+#include <popper.h>
 
 /* 
  *  dele:   Delete a message from the POP maildrop
