@@ -4,6 +4,10 @@
  * specifies the terms and conditions for redistribution.
  */
 
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
+
 
 /*
  * When adding each line length into the size of the message and the maildrop,
@@ -12,49 +16,48 @@
  * with a <cr><lf>.
  */
 
-
-#ifndef lint
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_dropcopy.c	2.6  2.6 4/3/91";
-#endif
-
+#include <config.h>
 
 #include <errno.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <ctype.h>
-#ifdef SYSV
-# include	<string.h>
-# include 	<unistd.h>	/* Maybe /sys/unistd.h on HPUX */
-# include	"flock.h"
-# ifndef index
+#include <string.h>
+#include <flock.h>
+
+#if HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+
+#if HAVE_SYS_UNISTD_H
+# include <sys/unistd.h>
+#endif
+
+#ifndef HAVE_INDEX
 #  define	index(s,c)		strchr(s,c)
-# endif
-# ifndef rindex
 #  define	rindex(s,c)		strrchr(s,c)
 # endif
-#else
+#if HAVE_STRINGS_H
 # include <strings.h>
 #endif
 #include <sys/stat.h>
 #include <sys/file.h>
 #include <pwd.h>
-#include "popper.h"
+#include <popper.h>
 
-
-#if defined(HAVE_UNISTD_H) || defined(SUNOS4)
-#include <unistd.h>
-#endif
+#include <md5.h>
 
 #ifdef MAILOCK
-# include <maillock.h>
+# ifdef HAVE_MAILLOCK
+#  include <maillock.h>
+# endif
+# define MAILUNLOCK() mailunlock()
+#else 
+# define MAILUNLOCK()
 #endif
 
-#if defined(SYSV) && !defined(L_XTND)
-# define L_XTND SEEK_END
-#endif
-
-#include "md5.h"
+#define MIN_UIDL_LENGTH 5     /* For no reason */
+#define MAX_UIDL_LENGTH 72    /* Including NL, Imposed by rfc1939 */
 
 /* This macro comes from Mark Crispin's c-client code */
 
@@ -135,7 +138,7 @@ int newline = 1;
  *	From Address [tty] date
  *	From [tty] date
  *
- *	"From [tty] date" is probably valid but I'm to lazy at this
+ *	"From [tty] date" is probably valid but I'm too lazy at this
  *	time to add the code.
  *
  */
@@ -312,7 +315,6 @@ POP *p;
 	    pop_log(p,POP_DEBUG, "Old .%s.pop file not found, errno (%d)",
 								p->user, errno);
 #endif
-
 	return(POP_SUCCESS);
     }
 
@@ -452,19 +454,17 @@ POP *p;
 	    } else if (!strncasecmp("X-UIDL:", buffer, 7)) {
 		if (!uidl_found) {
 		    char *cp;
+		    int len;
 
-		    uidl_found++;
 		    /* Skip over header string */
-		    cp = buffer;
-		    if (cp = index(buffer, ':')) {
-			cp++;
-			while (*cp && (*cp == ' ' || *cp == '\t')) cp++;
-		    } else
-			cp = "";
-
-		    mp->uidl_str = (char *)strdup(cp);
-		    mp->length += nchar + 1;
-		    p->drop_size += nchar + 1;
+		    cp = &buffer[7];
+                    while (*cp && (*cp == ' ' || *cp == '\t')) cp++;
+		    if( (len = strlen(cp)) > MIN_UIDL_LENGTH && len < MAX_UIDL_LENGTH ) {
+			uidl_found++;
+			mp->uidl_str = (char *)strdup(cp);
+			mp->length += nchar + 1;
+			p->drop_size += nchar + 1;
+		    }
 		}
 		continue;  /* Do not include this value in the message size */
 	    } else if ((strncasecmp(buffer,"Status:",7) == 0)) {
@@ -688,21 +688,20 @@ POP	*p;
 		MD5Update(&mdContext,(unsigned char *)buffer,strlen(buffer));
 	    } else if (!strncasecmp("X-UIDL:", buffer, 7)) {
 		if (!uidl_found) {
+		    int len;
 		    char *cp;
 
 		    uidl_found++;
 
 		    /* Skip over header */
-		    cp = buffer;
-		    if (cp = index(buffer, ':')) {
-			cp++;
-			while (*cp && (*cp == ' ' || *cp == '\t')) cp++;
-		    } else
-			cp = "";
-
-		    mp->uidl_str = (char *)strdup(cp);
-		    mp->length += nchar + 1;
-		    p->drop_size += nchar + 1;
+		    cp = &buffer[7];
+                    while (*cp && (*cp == ' ' || *cp == '\t')) cp++;
+		    if( (len = strlen(cp)) > MIN_UIDL_LENGTH && len < MAX_UIDL_LENGTH ) {
+			uidl_found++;
+			mp->uidl_str = (char *)strdup(cp);
+			mp->length += nchar + 1;
+			p->drop_size += nchar + 1;
+		    }
 		}
 		continue;  /* Do not include this value in the message size */
 	    } else if (!strncasecmp(buffer,"Status:",7)) {
@@ -787,7 +786,7 @@ struct passwd	*	pwp;
         if ((p->bull_db = dbm_open (bull_db, O_RDWR | O_CREAT, 0600)) == NULL) 
 #endif
 		{
-pop_log(p,POP_PRIORITY,"gdbm_open failed : %s (%d)",sys_errlist[errno],errno);
+pop_log(p,POP_PRIORITY,"[g]dbm_open failed : %s (%d)",sys_errlist[errno],errno);
 	    return(pop_msg(p, POP_FAILURE,
 	       "Unable to open Bulletin database, contact your administrator"));
 		}
@@ -831,7 +830,7 @@ pop_log(p,POP_PRIORITY,"gdbm_open failed : %s (%d)",sys_errlist[errno],errno);
 	return(pop_msg(p, POP_FAILURE, "Temporary drop file not owned by %s.",
 	    p->user));
     }
-#ifdef NEXT
+#ifdef NeXT
     if (mybuf.st_mode & (0x7)) {
 #else
     if (mybuf.st_mode & (S_IWOTH | S_IROTH)) {
@@ -912,8 +911,6 @@ pop_log(p,POP_PRIORITY,"gdbm_open failed : %s (%d)",sys_errlist[errno],errno);
 	/* Sync with stdio */
 	(void)fseek(p->drop, 0L, SEEK_END);
 	offset = ftell(p->drop);
-    /* Get the location of the next file */
-/*    offset = lseek(fileno(p->drop), (OFF_T)0, L_XTND); */
     }
 
 #ifdef MAILOCK
@@ -928,9 +925,7 @@ pop_log(p,POP_PRIORITY,"gdbm_open failed : %s (%d)",sys_errlist[errno],errno);
         if (flock (mfd,LOCK_EX) == -1)
 	{
             (void)close(mfd) ;
-#ifdef MAILOCK
-	    mailunlock();
-#endif
+	    MAILUNLOCK();
             return pop_msg(p,POP_FAILURE, "flock: '%s': %s (%d)", p->temp_drop,
                 (errno < sys_nerr) ? sys_errlist[errno] : "", errno);
         }
@@ -960,13 +955,13 @@ pop_log(p,POP_PRIORITY,"gdbm_open failed : %s (%d)",sys_errlist[errno],errno);
 	    /* Save the temporary drop FILE and fid values */
 	    p->hold = p->drop;
 	    if ((p->drop = fdopen(mfd,"r+")) == NULL) {
-		(void)close(dfd) ;
-		return pop_msg(p,POP_FAILURE,"Cannot assign stream for %s (%d)",
+		pop_msg(p,POP_FAILURE,"Cannot assign stream for %s (%d)",
 		    p->drop_name, errno);
+		goto bailout;
 	    }
 
 	    if (init_dropinfo(p) != POP_SUCCESS)
-		return(POP_FAILURE);
+		goto bailout;
 
 	    dfd = mfd;
 	}
@@ -980,23 +975,29 @@ pop_log(p,POP_PRIORITY,"gdbm_open failed : %s (%d)",sys_errlist[errno],errno);
 	(void)ftruncate(dfd, (OFF_T)offset);
     }
 #ifdef BULLDB
+    if(p->bulldir != NULL && p->bull_db != NULL) {
 #ifdef GDBM
-    gdbm_close(p->bull_db);
+        gdbm_close(p->bull_db);
 #else
-    dbm_close(p->bull_db);
+        dbm_close(p->bull_db);
 #endif
+	p->bull_db = NULL;
+    }
 #endif
-
     (void)fseek(p->drop, 0L, SEEK_END);
     p->spool_end = ftell(p->drop);
 
-#ifdef MAILOCK
-    mailunlock();
-#endif
-
+    MAILUNLOCK();
     if (p->server_mode)
         flock(mfd, LOCK_UN);
 
     return(POP_SUCCESS);
+ bailout:
+    MAILUNLOCK();
+    flock(mfd, LOCK_UN);
+    flock(dfd, LOCK_UN);
+    close(mfd);
+    close(dfd);
+    return( POP_FAILURE );
 }
 
