@@ -4,19 +4,21 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#ifndef lint
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_get_subcommand.c	2.1  2.1 3/18/91";
-#endif /* not lint */
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
 
+
+#include <config.h>
 #include <stdio.h>
 #include <sys/types.h>
-#if defined(SOLARIS2) || defined(SYSV) || defined(AIX)
 #include <string.h>
-#else
+
+#if HAVE_STRINGS_H
 #include <strings.h>
 #endif
-#include "popper.h"
+
+#include <popper.h>
 
 /* 
  *  get_subcommand: Extract a POP XTND subcommand from a client input line
@@ -41,7 +43,7 @@ POP     *   p;
             /*  Were too few parameters passed to the subcommand? */
             if ((p->parm_count-1) < s->min_parms) {
                 pop_msg(p,POP_FAILURE,
-                    "Too few arguments for the %s %s command.",
+                    "Too few arguments for the %.128s %.128s command.",
                         p->pop_command,p->pop_subcommand);
                 return((xtnd_table *)0);
             }
@@ -50,7 +52,7 @@ POP     *   p;
             /*  Were too many parameters passed to the subcommand? */
             if ((p->parm_count-1) > s->max_parms) {
                 pop_msg(p,POP_FAILURE,
-                    "Too many arguments for the %s %s command.",
+                    "Too many arguments for the %.128s %.128s command.",
                         p->pop_command,p->pop_subcommand);
                 return((xtnd_table *)0);
             }
@@ -63,6 +65,6 @@ POP     *   p;
     }
     /*  The client subcommand was not located in the XTND command table */
     pop_msg(p,POP_FAILURE,
-            "Unknown command: \"%s %s\".",p->pop_command,p->pop_subcommand);
+            "Unknown command: \"%.128s %.128s\".",p->pop_command,p->pop_subcommand);
     return((xtnd_table *)0);
 }
