@@ -4,39 +4,45 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#ifndef lint
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_init.c	2.1  2.1 3/18/91";
-#endif /* not lint */
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
+
+#include <config.h>
 
 #include <errno.h>
 #include <stdio.h>
 #include <sys/types.h>
-#ifdef POPSCO
+
+#if HAVE_SYS_NETINET_IN_H
 # include <sys/netinet/in.h>
-#else
+#endif
+#if HAVE_NETINET_IN_H
 # include <netinet/in.h>
 #endif
+
 #include <netdb.h>
 #include <arpa/inet.h>
-#include <sys/param.h>
+#include <string.h>
 
-#if defined(SOLARIS2) || defined(SYSV) || defined(AIX)
-#include	<string.h>
-#define bcopy(src,dest,len)	(void) (memcpy(dest,src,len))
-#define bzero(dest,len)  	(void) (memset(dest, (char)NULL, len))
-#define bcmp(b1,b2,n)		memcmp(b1,b2,n)
-#ifndef index
-# define index(s,c)		strchr(s,c)
+#if HAVE_SYS_PARAM_H
+# include <sys/param.h>
 #endif
-#ifndef rindex
-# define rindex(s,c)		strrchr(s,c)
-#endif
-#else
-#include <strings.h>
+#if HAVE_STRINGS_H
+# include <strings.h>
 #endif
 
-#include "popper.h"
+#ifndef HAVE_INDEX
+# define index(s,c) strchr(s,c)
+# define rindex(s,c) strrchr(s,c)
+#endif
+#ifndef HAVE_BCOPY
+# define bcopy(src,dest,len)   (void) (memcpy(dest, src, len))
+# define bzero(dest,len)       (void) (memset(dest, (char)NULL, len))
+# define bcmp(b1,b2,n)         memcmp(b1,b2,n)
+#endif
+
+#include <popper.h>
 
 /* CNS Kerberos IV */
 #ifdef KERBEROS
@@ -50,7 +56,7 @@ extern struct state	_res;
 #endif
 */
 
-#ifdef STRDUP
+#ifndef HAVE_STRDUP
 #include <stddef.h>
 #include <stdlib.h>
 
@@ -142,6 +148,7 @@ char    **      argmessage;
     p->mmdf_separator = NULL;
     p->bulldir = BULLDIR;
     p->dirty = 0;
+    p->xmitting = 0;
     p->kerberos = 0;
 #ifdef SERVER_MODE
     p->server_mode = 1;
