@@ -4,14 +4,19 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#ifndef lint
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_log.c	2.1  2.1 3/18/91";
-#endif
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
 
+#include <config.h>
 #include <stdio.h>
 #include <sys/types.h>
+#ifdef __STDC__
+#include <stdlib.h>
+#include <stdarg.h>
+#else
 #include <varargs.h>
+#endif
 #include "popper.h"
 
 /* 
@@ -20,35 +25,44 @@ static char SccsId[] = "@(#)@(#)pop_log.c	2.1  2.1 3/18/91";
 
 static char msgbuf[MAXLINELEN];
 
+#ifdef __STDC__
+pop_log(POP *p, int stat, const char *format,...)
+#else
 pop_log(va_alist)
 va_dcl
+#endif
 {
     va_list     ap;
+#ifndef __STDC__
     POP     *   p;
     int         stat;
     char    *   format;
+#endif
 #ifdef PYRAMID
     char    *   arg1, *arg2, *arg3, *arg4, *arg5, *arg6;
 #endif
     char    *   date_time;
     time_t	clock;
 
+
+    /* Get the information in to msgbuf */
+#ifdef __STDC__
+    va_start(ap,format);
+#else
     va_start(ap);
     p = va_arg(ap,POP *);
     stat = va_arg(ap,int);
     format = va_arg(ap,char *);
-#ifdef PYRAMID
+#endif
+#ifdef HAVE_VPRINTF
+        vsprintf(msgbuf,format,ap);
+#else
     arg1 = va_arg(ap, char *);
     arg2 = va_arg(ap, char *);
     arg3 = va_arg(ap, char *);
     arg4 = va_arg(ap, char *);
     arg5 = va_arg(ap, char *);
     arg6 = va_arg(ap, char *);
-#endif
-
-#ifdef HAVE_VSPRINTF
-        vsprintf(msgbuf,format,ap);
-#else
 # ifdef PYRAMID
         (void)sprintf(msgbuf,format, arg1, arg2, arg3, arg4, arg5, arg6);
 # else
