@@ -4,15 +4,15 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#ifndef lint
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-#endif
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
 
+#include <config.h>
 #include <stdio.h>
 #include <sys/types.h>
-#ifdef SYSV
 #include <string.h>
-#else
+#if HAVE_STRINGS_H
 #include <strings.h>
 #endif
 #include <pwd.h>
