@@ -4,11 +4,11 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#ifndef lint
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_rset.c	2.1  2.1 3/18/91";
-#endif not lint
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
 
+#include <config.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include "popper.h"
