@@ -4,28 +4,27 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#ifndef lint
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_send.c	2.1  2.1 3/18/91";
-#endif not lint
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
 
+#include <config.h>
 #include <stdio.h>
 #include <sys/types.h>
-#if defined(SOLARIS2) || defined(SYSV) || defined(AIX)
 #include <string.h>
-#define bcopy(src,dest,len)	(void) (memcpy(dest,src,len))
-#define bzero(dest,len)  	(void) (memset(dest, (char)NULL, len))
-#define bcmp(b1,b2,n)		(void) (memcmp(b1,b2,n))
-#ifndef index
-# define index(s,c)		strchr(s,c)
+#ifndef HAVE_BCOPY
+# define bcopy(src,dest,len)	(void) (memcpy(dest,src,len))
+# define bzero(dest,len)  	(void) (memset(dest, (char)NULL, len))
+# define bcmp(b1,b2,n)		(void) (memcmp(b1,b2,n))
 #endif
-#ifndef rindex
+#ifndef HAVE_INDEX
+# define index(s,c)		strchr(s,c)
 # define rindex(s,c)		strrchr(s,c)
 #endif
-#else
-#include <strings.h>
+#if HAVE_STRINGS_H
+# include <strings.h>
 #endif
-#include "popper.h"
+#include <popper.h>
 
 /* 
  *  send:   Send the header and a specified number of lines 
@@ -150,7 +149,7 @@ char        *   buffer;
     (void)fputs(buffer,p->output);
 
 #ifdef DEBUG
-    if(p->debug)pop_log(p,POP_DEBUG,"Sending line \"%s\"",buffer);
+    if(p->debug)pop_log(p,POP_DEBUG,"Sending line \"%.1000s\"",buffer);
 #endif
 
     /*  Put a <CR><NL> if a newline was removed from the buffer */
