@@ -1,15 +1,18 @@
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
+
+#include <config.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/file.h>
 #include <sys/wait.h>
 #include <ctype.h>
-
-#if defined(SOLARIS2) || defined(SYSV) || defined(AIX)
 #include <string.h>
-#ifndef index
+#ifndef HAVE_INDEX
 # define index(s,c)		strchr(s,c)
 #endif
-#else
+#if HAVE_STRINGS_H
 #include <strings.h>
 #endif
 
@@ -71,12 +74,7 @@ POP     *   p;
 	    if (mp->del_flag) continue;
 
 	    sprintf(buffer, "%d %s", x, mp->uidl_str);
-/*	    nl = index(mp->uidl_str, NEWLINE); */
 	    pop_sendline(p, buffer);
-/*
-	    if (!nl)
-		fprintf(p->output, "\n");
-*/
         }
     }
 
@@ -98,7 +96,8 @@ from_hdr(p, mp)
      POP         *p;
      MsgInfoList *mp;
 {
-  char buf[MAXLINELEN], *cp;
+  static char buf[MAXLINELEN];
+  char *cp;
 
     fseek(p->drop, mp->offset, 0);
     while (fgets(buf, sizeof(buf), p->drop) != NULL) {
@@ -149,7 +148,7 @@ POP     *   p;
 
 	sprintf(buffer, "%d %s", msg_id, mp->uidl_str);
         if (nl = index(buffer, NEWLINE)) *nl = 0;
-	sprintf(buffer, "%s %d %s", buffer, mp->length, from_hdr(p, mp));
+	sprintf(buffer, "%s %d %.128s", buffer, mp->length, from_hdr(p, mp));
 	return (pop_msg (p,POP_SUCCESS, buffer));
       }
     } else {
@@ -166,7 +165,7 @@ POP     *   p;
 
 	    sprintf(buffer, "%d %s", x, mp->uidl_str);
 	    if (nl = index(buffer, NEWLINE)) *nl = 0;	    
-	    sprintf(buffer, "%s %d %s", buffer, mp->length, from_hdr(p, mp));
+	    sprintf(buffer, "%s %d %.128s", buffer, mp->length, from_hdr(p, mp));
 	    pop_sendline(p, buffer);
         }
     }
