@@ -4,37 +4,38 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#ifndef lint
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_updt.c	2.3  2.3 3/20/91";
-#endif 
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
 
+#include <config.h>
 #include <errno.h>
 #include <stdio.h>
 #include <sys/types.h>
-#ifdef SYSV
 # include <string.h>
+#if HAVE_UNISTD_H
 # include <unistd.h>
-# include "flock.h"
-#else
+#endif
+#include <flock.h>
+#if HAVE_STRINGS_H
 # include <strings.h>
 #endif
 #include <sys/stat.h>
 #include <sys/file.h>
-#include "popper.h"
+#include <popper.h>
 
 #ifdef MAILOCK
 # include <maillock.h>
 #endif
 
-#if defined(SYSV) && !defined(L_XTND)
+#if !defined(L_XTND)
 #define L_XTND SEEK_END
 #endif
-#if defined(SYSV) && !defined(L_SET)
+#ifndef L_SET
 #define L_SET SEEK_SET
 #endif
 
-#if defined(HAVE_UNISTD_H) || defined(SUNOS4)
+#if defined(HAVE_UNISTD_H)
 #include <unistd.h>
 #endif
 
