@@ -4,10 +4,11 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#ifndef lint
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_xmit.c	2.1  2.1 3/18/91";
-#endif
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
+
+#include <config.h>
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -20,34 +21,30 @@ static char SccsId[] = "@(#)@(#)pop_xmit.c	2.1  2.1 3/18/91";
 
 #include <sys/wait.h>
 
-#if defined(SOLARIS2) || defined(UNIXWARE) || defined(AIX) || defined(PTX) \
-	|| defined(AUX)
+#if HAVE_SYS_STAT_H
 #include <sys/stat.h>
+#endif
+
+#if HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
 
-#include "popper.h"
+#include <popper.h>
 
 /*
  *  xmit:   POP XTND function to receive a message from 
  *          a client and send it in the mail
  */
 
+FILE *tmp; /* File descriptor for temporary file */
+char temp_xmit[MAXDROPLEN]; /* Name of the temporary filedrop */
+
+
 pop_xmit (p)
 POP     *   p;
 {
-    FILE                *   tmp;                    /*  File descriptor for 
-                                                        temporary file */
     int			    tfn;		    
-    char                    buffer[MAXLINELEN];     /*  Read buffer */
-    char                    temp_xmit[MAXDROPLEN];  /*  Name of the temporary 
-                                                        filedrop */
-#ifdef NEXT
-    union	wait	    stat;
-#else
-    int			    stat;
-#endif
-    PID_T                   id, pid;
+
 
     /*  Create a temporary file into which to copy the user's message */
 
@@ -65,33 +62,49 @@ POP     *   p;
                 temp_xmit, errno));
     }
 
-    /*  Tell the client to start sending the message */
-    pop_msg(p,POP_SUCCESS,"Start sending the message.");
-
     /*  Receive the message */
 #ifdef DEBUG
     if(p->debug)pop_log(p,POP_DEBUG,"Receiving mail message");
 #endif
-    while (fgets(buffer,MAXLINELEN,p->input)){
-        /*  Look for initial period */
-#ifdef DEBUG
-        if(p->debug)pop_log(p,POP_DEBUG,"Receiving: \"%s\"",buffer);
-#endif
-        if (*buffer == '.') {
-            /*  Exit on end of message */
-            if (strcmp(buffer,".\r\n") == 0)
-	         break;
-	    /* sendmail will not remove escaped .. */
-	    else if (buffer[1] == '.') {
-		(void)fputs (&buffer[1], tmp);
-	    } else {
-		(void)fputs (buffer, tmp);
-	    }
-        } else
-	    (void)fputs (buffer, tmp);
-    }
-    (void)fclose (tmp);
+    p->xmitting = 1;
+    return(pop_msg(p,POP_SUCCESS,"Start sending message."));
+}
 
+pop_xmit_recv(p,buffer)
+POP  *p;
+char *buffer;
+{
+
+    /*  Look for initial period */
+#ifdef DEBUG
+    if(p->debug)pop_log(p,POP_DEBUG,"Receiving: \"%.1000s\"",buffer);
+#endif
+    if (*buffer == '.') {
+        /*  Exit on end of message */
+        if (strcmp(buffer,".\r\n") == 0) {
+            (void) fclose(tmp);
+            p->xmitting = 0;
+            pop_xmit_exec(p);
+        }
+        /* sendmail will not remove escaped .. */
+	else if (buffer[1] == '.') 	(void)fputs (&buffer[1], tmp);
+	else 	(void)fputs (buffer, tmp);
+    } else    (void)fputs (buffer, tmp);
+}
+
+
+    
+pop_xmit_exec(p)
+POP *p;
+{
+
+#ifdef NeXT
+    union	wait	    stat;
+#else
+    int			    stat;
+#endif
+    PID_T                   id, pid;
+    
 #ifdef DEBUG
     if(p->debug)pop_log(p,POP_DEBUG,"Forking for \"%s\"",MAIL_COMMAND);
 #endif
@@ -113,7 +126,7 @@ POP     *   p;
             (void)close(0);
             if (open(temp_xmit,O_RDONLY,0) < 0)
 		(void)_exit(1);
-            (void)execl (MAIL_COMMAND,"send-mail","-t","-oem",NULLCP);
+            (void)execl (MAIL_COMMAND,"send-mail","-t","-i","-oem",NULLCP);
             (void)_exit(1);
         case -1:
             if (!p->debug) (void)unlink (temp_xmit);
@@ -121,14 +134,14 @@ POP     *   p;
 							MAIL_COMMAND, errno));
         default:
 
-#ifdef NEXT
+#ifdef NeXT
             while((id = wait(&stat)) >=0 && id != pid);
 #else
             id = waitpid(pid, &stat, 0);
 #endif
             if (!p->debug) (void)unlink (temp_xmit);
 
-#ifdef NEXT
+#ifdef NeXT
             if (!WIFEXITED (stat))
 #else
             if ((!WIFEXITED (stat)) || (WEXITSTATUS (stat) != 0))
@@ -139,3 +152,11 @@ POP     *   p;
     }
 }
 
+pop_xmit_clean(p)
+POP *p;
+{
+    fclose(tmp);
+    if (!p->debug) (void)unlink (temp_xmit);
+}
+
+
