@@ -1,14 +1,20 @@
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
+
 /*  */
 /* popauth.c - manipulate POP authorization DB */
-#ifndef	lint
-static char ident[] = "@(#)$Id: popauth.c,v 1.9 1996/05/30 00:37:41 mark Exp mark $";
-#endif	/* lint */
-
-#undef	DBM		/* used by mts.c and ndbm.h */
+#include <config.h>
 #ifdef GDBM
-#include <gdbm.h>
+# include <gdbm.h>
 #else
-#include <ndbm.h>
+# if HAVE_NDBM_H
+#  include <ndbm.h>
+# else
+#  if HAVE_DBM_H
+#   include <dbm.h>
+#  endif
+# endif
 #endif
 #include <pwd.h>
 #include <stdio.h>
@@ -22,21 +28,22 @@ static char ident[] = "@(#)$Id: popauth.c,v 1.9 1996/05/30 00:37:41 mark Exp mar
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
+#include <string.h>
 
-#if defined(SOLARIS2) || defined(SYSV) || defined(AIX)
-#include	<string.h>
+#ifndef HAVE_BCOPY
 #define bcopy(src,dest,len)	(void) (memcpy(dest,src,len))
 #define bzero(dest,len)  	(void) (memset(dest, (char)NULL, len))
 #define bcmp(b1,b2,n)		memcmp(b1,b2,n)
-#ifndef index
-# define index(s,c)		strchr(s,c)
 #endif
-#ifndef rindex
+#ifndef HAVE_INDEX
+# define index(s,c)		strchr(s,c)
 # define rindex(s,c)		strrchr(s,c)
 #endif
-#include "flock.h"
-#else
+#include <flock.h>
+#if HAVE_STRINGS_H
 #include <strings.h>
+#endif
+#if HAVE_SYS_FILE_H
 #include <sys/file.h>
 #endif
 
@@ -44,7 +51,7 @@ static char ident[] = "@(#)$Id: popauth.c,v 1.9 1996/05/30 00:37:41 mark Exp mar
 #define BSD44_DBM
 #endif
 
-#ifdef NEED_STRERROR
+#ifndef HAVE_STRERROR
 char *strerror();
 #endif
 
@@ -95,7 +102,7 @@ va_dcl
 	/*NOTREACHED*/
 }
 
-#ifdef STRDUP
+#ifndef HAVE_STRDUP
 #include <stddef.h>
 
 char *
@@ -628,7 +635,7 @@ char   *argv[];
     /* NOTREACHED */
 }
 
-#ifdef NEED_STRERROR
+#ifndef HAVE_STRERROR
 char *
 strerror(e)
 	int e;
