@@ -3,11 +3,11 @@
  * All rights reserved.  The Berkeley software License Agreement
  * specifies the terms and conditions for redistribution.
  */
+/*
+ * Copyright (c) 1997 by Qualcomm Incorporated.
+ */
 
-#ifndef lint
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)popper.c	2.1  2.1 3/18/91";
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -31,14 +31,18 @@ static char SccsId[] = "@(#)@(#)popper.c	2.1  2.1 3/18/91";
 # endif
 #endif
 
-#if defined(OSF1) && defined(AUTH)
-#include <sys/security.h>
-#include <prot.h>
+#if defined(AUTH_SPECIAL)
+# ifdef HAVE_SYS_SECURITY_H 
+#  include <sys/security.h>
+# endif
+# ifdef HAVE_PROTO_H
+#  include <prot.h>
+# endif
 #endif
 
-#include "popper.h"
+#include <popper.h>
 
-#ifdef NEED_STRERROR
+#ifndef HAVE_STRERROR
 char * strerror();
 #endif
 
@@ -54,7 +58,7 @@ FILE *debuglog;
 /* 
  *  popper: Handle a Post Office Protocol version 3 session
  */
-main (argc, argv) 
+main (argc, argv)
 int         argc;
 char    **  argv;
 {
@@ -63,7 +67,7 @@ char    **  argv;
     char                message[MAXLINELEN];
     char            *   tgets();
 
-#if (defined(POPSCO) || defined(OSF1)) && defined(AUTH)
+#if defined(AUTH_SPECIAL) && defined(HAVE_SET_AUTH_PARAMETERS)
     (void) set_auth_parameters(argc, argv);
 #endif
 
@@ -118,8 +122,11 @@ char    **  argv;
 #endif
             p.CurrentState = error;
         } else if (tgets(message,MAXLINELEN,p.input,pop_timeout) == NULL) {
-	    if (poptimeout)
-		pop_msg(&p,POP_FAILURE,"POP timeout",p.myhost);
+	    if (poptimeout) {
+                if (p.xmitting) pop_xmit_clean(&p);
+		pop_msg(&p,POP_FAILURE,"POP timeout",p.myhost); 
+            }
+            
 	    else
 		pop_msg(&p,POP_FAILURE,"POP EOF received",p.myhost);
 #ifndef NOUPDATEONABORT
@@ -132,6 +139,8 @@ char    **  argv;
                 pop_msg(&p,POP_FAILURE,"POP mailbox restoration failed!",p.myhost);
 #endif
             p.CurrentState = error;
+        } else if (p.xmitting) { /* After the xtnd xmit initiates the mail txfer */
+            pop_xmit_recv(&p,message);
         } else if ((s = pop_get_command(&p,message)) != NULL) {
             if (s->function != NULL) {
 #ifdef SETPROCTITLE
@@ -274,13 +283,7 @@ int catchSIGHUP()
     signal(SIGPIPE,  VOIDSTAR catchSIGHUP);
 }
 
-/*
- * $Author: qpop $ $Date: 1997/03/14 05:01:07 $
- * $Header: /users/sources/Qpopper/popper.c,v 1.1.1.1 1997/03/14 05:01:07 qpop Exp $
- * $Revision: 1.1.1.1 $
- */
-
-#ifdef NEED_STRERROR
+#ifndef HAVE_STRERROR
 char *
 strerror(e)
 	int e;
@@ -334,7 +337,7 @@ ftruncate(fd,length)
 }
 #endif
 
-#ifdef NEED_FTRUNCATE
+#ifndef HAVE_FTRUNCATE
 /* ftruncate emulations that work on some System V's.
    This file is in the public domain.  */
 
@@ -438,5 +441,5 @@ ftruncate (fd, length)
 #endif /* not HAVE_CHSIZE */
 #endif /* not F_FREESP */
 #endif /* not F_CHSIZE */
-#endif /* NEED_FTRUNCATE */
+#endif /*! HAVE_FTRUNCATE */
 
